Using Different Storage Backends
=======================================

LMCache supports various storage backends to offload and share KV cache data.

Supported Backends
-------------------------

.. toctree::
   :maxdepth: 1

   cpu_ram
   local_storage
   gds
   redis
   s3
   infinistore
   mooncake
   valkey
   weka
   nixl
   external_backend